# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-06-14 07:58
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('bee_django_mission', '0007_auto_20180613_1555'),
    ]

    operations = [
        migrations.CreateModel(
            name='CustomUserMission',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('custom_name', models.CharField(blank=True, max_length=180, null=True, verbose_name='\u81ea\u5b9a\u4e49\u540d\u5b57')),
                ('custom_count', models.IntegerField(blank=True, null=True, verbose_name='\u81ea\u5b9a\u4e49\u6570\u91cf')),
                ('mission', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bee_django_mission.Mission')),
                ('stage', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bee_django_mission.Stage')),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'ordering': ['pk'],
                'db_table': 'bee_django_mission_custom_user_mission',
                'verbose_name': '\u5b66\u751f\u81ea\u5b9a\u4e49\u4efb\u52a1',
            },
        ),
    ]
