{% extends "bee_django_mission/base.html" %}
{% load static %}
{% load bootstrap3 %}
{% block content %}
    {% include 'bee_django_mission/logo.html' %}
    {% include 'bee_django_mission/nav.html' %}
    {#    <h4>修改【{{ mission.name }}】</h4>#}

    <h4>为{{ user }}添加任务线</h4>
    <div>
        <form method="post">
            {% csrf_token %}
            {#        {{ form.as_ul }}#}
            {% bootstrap_form form %}
            {% bootstrap_button "提交" %}
            {#        <input type="submit" value="提交"/>#}
        </form>
    </div>
{% endblock %}


{% block scripts %}
    <script>
        $(document).ready(function () {

        });
    </script>
{% endblock %}