# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-06-14 09:29
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_mission', '0009_auto_20180614_1705'),
    ]

    operations = [
        migrations.AddField(
            model_name='userstage',
            name='prize_coin',
            field=models.IntegerField(default=0, verbose_name='\u5956\u52b1\u7684m\u5e01'),
        ),
    ]
