# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-06-13 07:55
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_mission', '0006_userstagetfinishcount'),
    ]

    operations = [
        migrations.RenameModel(
            old_name='UserStagetFinishCount',
            new_name='UserStageFinishCount',
        ),
    ]
